==> tuia-news-center-api-0.0.67-xt4-20180919.091701-1-sources.jar: cn/com/duiba/tuia/news/center/dto/rsp/AccountBalanceV2Dto.java <==
package cn.com.duiba.tuia.news.center.dto.rsp;

import cn.com.duiba.tuia.news.center.dto.BindingDto;
import cn.com.duiba.tuia.news.center.dto.RewardDto;

import java.io.Serializable;

/**
 * @author ZhouFeng zhoufeng@duiba.com.cn
 * @version $Id: AccountBalanceDto.java , v 0.1 2018/1/3 下午2:18 ZhouFeng Exp $
 */
public class AccountBalanceV2Dto implements Serializable{

    private static final long serialVersionUID = -3845881204167292130L;
    /**
     * 零钱余额
     */
    private Long changeBalance;

    /**
     * 今日金币余额
     */
    private Long owncoinBalance;

    /**
     * 绑定情况
     */
    private BindingDto bindingDto;

    /**
     * 用户名称
     */
    private String nickName;

    /**
     * 头像
     */
    private String headImage;

    public String getNickName() {
        return nickName;
    }

    public void setNickName(String nickName) {
        this.nickName = nickName;
    }

    public String getHeadImage() {
        return headImage;
    }

    public void setHeadImage(String headImage) {
        this.headImage = headImage;
    }

    public Long getOwncoinBalance() {
        return owncoinBalance;
    }

    public void setOwncoinBalance(Long owncoinBalance) {
        this.owncoinBalance = owncoinBalance;
    }

    public BindingDto getBindingDto() {
        return bindingDto;
    }

    public void setBindingDto(BindingDto bindingDto) {
        this.bindingDto = bindingDto;
    }

    public Long getChangeBalance() {
        return changeBalance;
    }

    public void setChangeBalance(Long changeBalance) {
        this.changeBalance = changeBalance;
    }

    public Long getCoinBalance() {
        return owncoinBalance;
    }

    public void setCoinBalance(Long coinBalance) {
        this.owncoinBalance = coinBalance;
    }
}

==> tuia-news-center-api-2.0.0.0-xt-20190403.025840-1-sources.jar: cn/com/duiba/tuia/news/center/dto/rsp/AccountBalanceV2Dto.java <==
package cn.com.duiba.tuia.news.center.dto.rsp;

import cn.com.duiba.tuia.news.center.dto.BindingDto;

import java.io.Serializable;

/**
 * @author ZhouFeng zhoufeng@duiba.com.cn
 * @version $Id: AccountBalanceDto.java , v 0.1 2018/1/3 下午2:18 ZhouFeng Exp $
 */
public class AccountBalanceV2Dto implements Serializable{

    private static final long serialVersionUID = -3845881204167292130L;
    /**
     * 零钱余额
     */
    private Long changeBalance;

    /**
     * 今日金币余额
     */
    private Long owncoinBalance;

    /**
     * 绑定情况
     */
    private BindingDto bindingDto;

    /**
     * 用户名称
     */
    private String nickName;

    /**
     * 头像
     */
    private String headImage;

    /**
     * 今日金币收益
     */
    private Long todayIncomeCoins;

    public String getNickName() {
        return nickName;
    }

    public void setNickName(String nickName) {
        this.nickName = nickName;
    }

    public String getHeadImage() {
        return headImage;
    }

    public void setHeadImage(String headImage) {
        this.headImage = headImage;
    }

    public Long getOwncoinBalance() {
        return owncoinBalance;
    }

    public void setOwncoinBalance(Long owncoinBalance) {
        this.owncoinBalance = owncoinBalance;
    }

    public BindingDto getBindingDto() {
        return bindingDto;
    }

    public void setBindingDto(BindingDto bindingDto) {
        this.bindingDto = bindingDto;
    }

    public Long getChangeBalance() {
        return changeBalance;
    }

    public void setChangeBalance(Long changeBalance) {
        this.changeBalance = changeBalance;
    }

    public Long getCoinBalance() {
        return owncoinBalance;
    }

    public void setCoinBalance(Long coinBalance) {
        this.owncoinBalance = coinBalance;
    }

    public Long getTodayIncomeCoins() {
        return todayIncomeCoins;
    }

    public void setTodayIncomeCoins(Long todayIncomeCoins) {
        this.todayIncomeCoins = todayIncomeCoins;
    }
}
